**ExtendedDateTimeFormattingBehavior** adds some methods for human-friendly date&time formatting to *CDateFormatter* component.

Available formatters:

* **formatDateTimeReadable**

    `formatDateTimeReadable($timestamp, $dateWidth = 'medium', $timeWidth = 'medium')` formats date&time with pattern **(Today|Yesterday|Tomorrow|&lt;date&gt;), &lt;time&gt;**.
    **$dateWidth** and **$timeWidth** passes directly to `CDateFormatter::formatDateTime()`.

    If you want change the order of date&time, specify **language** option of behavior object. It's value will be used as a locale ID and it's `dateTimeFormat` property will define order.

    Example: `Today, 8:45:17 PM`

* **formatDateTimeInterval**

    `formatDateTimeInterval($timestamp, $precisely = false)` formats date&time as a date&time interval with pattern **&lt;metric value&gt; &lt;metric&gt; ago** or more complex **&lt;first metric value&gt; &lt;first metric&gt; and &lt;second metric value&gt; &lt;second metric&gt; ago**.

    **$precisely** defines precision of calculation.

    Example: `20 hours and 54 minutes ago`

* **formatDateTimeIntervalWide**

    `formatDateTimeIntervalWide($datetime)` formats date&time as an interval with pattern "years, months, days, hours, minutes and seconds ago".

    Example: `73 years, 2 months, 7 days, 39 minutes and 59 seconds ago`

**$timestamp** in both formatters can be unix timestamp (integer) or string to pass it to `strtotime()`.
**$datetime** in the last formatter can be string or unix timestamp (integer) to pass it to `date('r', $datetime)`.
Both interval formatters support dates in future:
```php
echo Yii::app()->dateFormatter->formatDateTimeInterval('tomorrow'); // in 18 hours
echo Yii::app()->dateFormatter->formatDateTimeIntervalWide('2038-01-19 03:14:08'); // in 23 years, 4 months, 20 days, 21 hours, 27 minutes and 8 seconds
```

---
How to use: attach this behavior to your dateFormatter instance.

For example, add this in your base controller class (`Controller`) and base console command class (`ConsoleCommand`):
```php
    public function init()
    {
        parent::init();
        Yii::app()->dateFormatter->attachBehavior('ExtendedDateTimeFormatting', 'ext.ExtendedDateTimeFormattingBehavior.ExtendedDateTimeFormattingBehavior');
    }
```
---

Examples:
```php
echo Yii::app()->dateFormatter->formatDateTimeInterval('today');
echo Yii::app()->dateFormatter->formatDateTimeInterval('tomorrow');
echo Yii::app()->dateFormatter->formatDateTimeInterval('yesterday');
```
returns
```
Today 00:00:00 am
Tomorrow 00:00:00 am
Yesterday 00:00:00 am
```

```php
echo Yii::app()->dateFormatter->formatDateTimeInterval('now');
echo Yii::app()->dateFormatter->formatDateTimeInterval('today');
echo Yii::app()->dateFormatter->formatDateTimeInterval('midnight');
echo Yii::app()->dateFormatter->formatDateTimeInterval('noon');
echo Yii::app()->dateFormatter->formatDateTimeInterval('tomorrow');
echo Yii::app()->dateFormatter->formatDateTimeInterval('yesterday');
echo Yii::app()->dateFormatter->formatDateTimeInterval('-1 year');
```
returns
```
just now
5 hours ago
5 hours ago
in 6 hours
in 18 hours
1 day ago
1 year ago
```

```php
echo Yii::app()->dateFormatter->formatDateTimeIntervalWide('1941-06-22 04:00');
echo Yii::app()->dateFormatter->formatDateTimeIntervalWide('2038-01-19 03:14:08');
```
returns
```
73 years, 2 months, 7 days, 50 minutes and 56 seconds ago
in 23 years, 4 months, 20 days, 21 hours, 23 minutes and 12 seconds
```
